@@ -1,3 +1,4 @@
+import os
 import subprocess
 import logging.config
 
@@ -39,6 +40,15 @@ MEDIA_PLUGINS = [
     "argus.notificationprofile.media.sms_as_email.SMSNotification",
 ]
 
+# Tests
+
+TEST_RUNNER = "xmlrunner.extra.djangotestrunner.XMLTestRunner"
+TEST_OUTPUT_VERBOSE = 2
+# This ensures that each tox environment receives test reports in separate directories. If not running tests under tox,
+# reports land directly in test-reports/
+TEST_OUTPUT_DIR = os.path.join("test-reports", os.getenv("TOX_ENV_NAME", ""))
+TEST_OUTPUT_FILE_NAME = "test-results.xml"
+
 # PSA for login
 
 SOCIAL_AUTH_DATAPORTEN_KEY = get_str_env("ARGUS_DATAPORTEN_KEY")
